summaryrefslogtreecommitdiffstats
path: root/libtdepim/broadcaststatus.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-19 11:59:01 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-19 11:59:01 -0600
commit716a5de8870d7c02bb4d0aed72f30291b17b763a (patch)
tree29e58b213ead28151ccf7eb33d12c968ea844120 /libtdepim/broadcaststatus.h
parent0e00c0a86a4c9d7e80c7b66d91940cc7dcb79f78 (diff)
downloadtdepim-716a5de8870d7c02bb4d0aed72f30291b17b763a.tar.gz
tdepim-716a5de8870d7c02bb4d0aed72f30291b17b763a.zip
Remove additional unneeded tq method conversions
Diffstat (limited to 'libtdepim/broadcaststatus.h')
-rw-r--r--libtdepim/broadcaststatus.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/libtdepim/broadcaststatus.h b/libtdepim/broadcaststatus.h
index 9173feaad..934d1cfa8 100644
--- a/libtdepim/broadcaststatus.h
+++ b/libtdepim/broadcaststatus.h
@@ -41,18 +41,18 @@ public:
/** Return the instance of the singleton object for this class */
static BroadcastStatus *instance();
/** Return the last status message from seStatusMsg() */
TQString statusMsg() const { return mStatusMsg; }
/** Sets a status bar message with timestamp */
- void seStatusMsgWithTimestamp( const TQString& message );
+ void setStatusMsgWithTimestamp( const TQString& message );
/** Sets a transmission completed status bar message */
- void seStatusMsgTransmissionCompleted( int numMessages,
+ void setStatusMsgTransmissionCompleted( int numMessages,
int numBytes = -1,
int numBytesRead = -1,
int numBytesToRead = -1,
bool mLeaveOnServer = false,
KPIM::ProgressItem* progressItem = 0 ); // set the same status in this progress item
- void seStatusMsgTransmissionCompleted( const TQString& account,
+ void setStatusMsgTransmissionCompleted( const TQString& account,
int numMessages,
int numBytes = -1,
int numBytesRead = -1,
@@ -63,7 +63,7 @@ public:
public slots:
/** Emit an update status bar signal. It's a slot so it can be hooked up
to other signals. */
- void seStatusMsg( const TQString& message );
+ void setStatusMsg( const TQString& message );
/**
Set a status message that will go away again with the next call of
@@ -78,7 +78,7 @@ public slots:
signals:
/** Emitted when seStatusMsg is called. */
void statusMsg( const TQString& );
protected:
@@ -41,18 +41,18 @@ public:
/** Return the instance of the singleton object for this class */
static BroadcastStatus *instance();
- /** Return the last status message from seStatusMsg() */
+ /** Return the last status message from setStatusMsg() */
TQString statusMsg() const { return mStatusMsg; }
/** Sets a status bar message with timestamp */
@@ -78,7 +78,7 @@ public slots:
signals:
- /** Emitted when seStatusMsg is called. */
+ /** Emitted when setStatusMsg is called. */
void statusMsg( const TQString& );
protected: